/**
 * WordPress dependencies
 */
import { __experimentalHStack as HStack } from '@wordpress/components';
import { decodeEntities } from '@wordpress/html-entities';
import { __ } from '@wordpress/i18n';
import { useSelect } from '@wordpress/data';
import { store as coreStore } from '@wordpress/core-data';

/**
 * Internal dependencies
 */

import { getItemTitle } from '../../actions/utils';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const TitleView = ({
  item
}) => {
  const {
    frontPageId,
    postsPageId
  } = useSelect(select => {
    const {
      getEntityRecord
    } = select(coreStore);
    const siteSettings = getEntityRecord('root', 'site');
    return {
      frontPageId: siteSettings?.page_on_front,
      postsPageId: siteSettings?.page_for_posts
    };
  }, []);
  const renderedTitle = getItemTitle(item);
  let suffix;
  if (item.id === frontPageId) {
    suffix = /*#__PURE__*/_jsx("span", {
      className: "edit-site-post-list__title-badge",
      children: __('Homepage')
    });
  } else if (item.id === postsPageId) {
    suffix = /*#__PURE__*/_jsx("span", {
      className: "edit-site-post-list__title-badge",
      children: __('Posts Page')
    });
  }
  return /*#__PURE__*/_jsxs(HStack, {
    className: "edit-site-post-list__title",
    alignment: "center",
    justify: "flex-start",
    children: [/*#__PURE__*/_jsx("span", {
      children: decodeEntities(renderedTitle) || __('(no title)')
    }), suffix]
  });
};
export default TitleView;
//# sourceMappingURL=title-view.js.map